@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -48,13 +46,13 @@ class IndexView(tables.DataTableView):
         results = []
         if page_offset is None:
             page_offset = 0
-        limit = utils.get_page_size(self.request)    
+        limit = utils.get_page_size(self.request)
         try:
             results = api.monitor.alarmdef_list(self.request, page_offset, limit)
             paginator = Paginator(results, limit)
             results = paginator.page(1)
         except EmptyPage:
-            contacts = paginator.page(paginator.num_pages)
+            results = paginator.page(paginator.num_pages)
         except Exception:
             messages.error(self.request, _("Could not retrieve alarm definitions"))
 
